@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2019  StorPool.
+# Copyright (c) 2019, 2020  StorPool.
 # All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -16,8 +16,14 @@
 #
 """ Mock the storpool.spconfig.SPConfig class for testing """
 
+try:
+    from typing import Dict, Optional
+except ImportError:
+    pass
+
 
 def get_config_dictionary():
+    # type: () -> Dict[str, str]
     """ Return the dictionary to be used for configuration. """
     return {
         "SP_OURID": "42",
@@ -32,12 +38,15 @@ class SPConfig(object):
     """ Mock the SPConfig class. """
 
     def __init__(self):
+        # type: (SPConfig) -> None
         self._dict = get_config_dictionary()
 
     def __getitem__(self, key):
+        # type: (SPConfig, str) -> str
         """ Return a configuration value. """
         return self._dict[key]
 
     def get(self, key, default=None):
+        # type: (SPConfig, str, Optional[str]) -> Optional[str]
         """ Return a configuration value with a fallback. """
         return self._dict.get(key, default)
